@@ -50,6 +50,8 @@ $LANG_POLLS = array(
     'upgrade1'          => 'You installed a new version of the Polls plugin. Please',
     'upgrade2'          => 'upgrade',
     'editinstructions'  => 'Please fill in the Poll ID, at least one question and two answers for it.',
+    'pollclosed'        => 'This poll is closed for voting.', 
+    'pollhidden'        => 'You have already voted. This poll results will only be shown when voting is closed.', 
     'start_poll'        => 'Start Poll'
 );
 
@@ -99,6 +101,7 @@ $LANG25 = array(
     40 => 'See all answers to this poll'
 );
 
+$PLG_polls_MESSAGE15 = 'Your comment has been submitted for review and will be published when approved by a moderator.';
 $PLG_polls_MESSAGE19 = 'Your poll has been successfully saved.';
 $PLG_polls_MESSAGE20 = 'Your poll has been successfully deleted.';
 
@@ -123,7 +126,8 @@ $LANG_confignames['polls'] = array(
     'polladdresstime' => 'Voter IP Address valid for',
     'delete_polls' => 'Delete Polls with Owner?',
     'aftersave' => 'After Saving Poll',
-    'default_permissions' => 'Poll Default Permissions'
+    'default_permissions' => 'Poll Default Permissions',
+    'meta_tags' => 'Enable Meta Tags'
 );
 
 $LANG_configsubgroups['polls'] = array(
