@@ -8,7 +8,7 @@
 // |                                                                           |
 // | Geeklog Calendarjp Plugin administration page.                            |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2008 by dengen - taharaxp AT gmail DOT com                  |
+// | Copyright (C) 2008-2009 by dengen - taharaxp AT gmail DOT com             |
 // |                                                                           |
 // | Calendarjp plugin is based on prior work by:                              |
 // | Authors: Tony Bibbs        - tony AT tonybibbs DOT com                    |
@@ -33,7 +33,14 @@
 // |                                                                           |
 // +---------------------------------------------------------------------------+
 
+/**
+* Geeklog common function library
+*/
 require_once '../../../lib-common.php';
+
+/**
+* Security check to ensure user even belongs on this page
+*/
 require_once '../../auth.inc.php';
 
 // Uncomment the line below if you need to debug the HTTP variables being passed
@@ -45,17 +52,14 @@ $display = '';
 
 // Ensure user even has the rights to access this page
 if (!SEC_hasRights('calendarjp.edit')) {
-    $display .= COM_siteHeader('menu', $MESSAGE[30]);
-    $display .= COM_startBlock ($MESSAGE[30], '',
-                                COM_getBlockTemplate ('_msg_block', 'header'));
-    $display .= $MESSAGE[35];
-    $display .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
-    $display .= COM_siteFooter();
+    $display .= COM_siteHeader('menu', $MESSAGE[30])
+             . COM_showMessageText($MESSAGE[29], $MESSAGE[30])
+             . COM_siteFooter();
 
-    // Log attempt to error.log
+    // Log attempt to access.log
     COM_accessLog("User {$_USER['username']} tried to illegally access the event administration screen.");
 
-    echo $display;
+    COM_output($display);
 
     exit;
 }
@@ -85,17 +89,20 @@ function CALENDARJP_editEvent ($mode, $A, $msg = '')
         $retval .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
     }
 
+    $ja = ($_CONF['language'] == 'japanese_utf-8');
+
     $event_templates = new Template($_CONF['path'] . 'plugins/calendarjp/templates/admin');
     if ( isset ($_CAJP_CONF['advanced_editor']) && ($_CAJP_CONF['advanced_editor'] == 1 ) ) {
-        $event_templates->set_file('editor','eventeditor_advanced.thtml');
+        $event_templates->set_file('editor','eventeditor_advanced' . ($ja ? '_ja' : '') . '.thtml');
     } else {
-        $event_templates->set_file('editor','eventeditor.thtml');
+        $event_templates->set_file('editor','eventeditor' . ($ja ? '_ja' : '') . '.thtml');
     }
     $event_templates->set_var( 'xhtml', XHTML );
     $event_templates->set_var('site_url', $_CONF['site_url']);
     $event_templates->set_var('site_admin_url', $_CONF['site_admin_url']);
     $event_templates->set_var('layout_url',$_CONF['layout_url']);
-    $event_templates->set_var('lang_allowed_html', COM_allowedHTML());
+    $event_templates->set_var('lang_allowed_html',
+                              COM_allowedHTML('calendarjp.edit'));
     $event_templates->set_var('lang_postmode', $LANG_CALJP_ADMIN[3]);
     $event_templates->set_var('lang_expandhelp', $LANG24[67]);
     $event_templates->set_var('lang_reducehelp', $LANG24[68]);
@@ -130,7 +137,9 @@ function CALENDARJP_editEvent ($mode, $A, $msg = '')
             return $retval;
         }
     } else {
-        $A['owner_id'] = $_USER['uid'];
+        if (empty($A['owner_id'])) {
+            $A['owner_id'] = $_USER['uid'];
+        }
         if (isset ($_GROUPS['Calendarjp Admin'])) {
             $A['group_id'] = $_GROUPS['Calendarjp Admin'];
         } else {
@@ -173,10 +182,11 @@ function CALENDARJP_editEvent ($mode, $A, $msg = '')
 
 
 
-
+    $token = SEC_createToken();
 
     $retval .= COM_startBlock($LANG_CALJP_ADMIN[1], '',
-                              COM_getBlockTemplate ('_admin_block', 'header'));
+                              COM_getBlockTemplate('_admin_block', 'header'));
+    $retval .= SEC_getTokenExpiryNotice($token);
 
     if (!empty($A['eid'])) {
         $delbutton = '<input type="submit" value="' . $LANG_ADMIN['delete']
@@ -216,6 +226,7 @@ function CALENDARJP_editEvent ($mode, $A, $msg = '')
         $A['allday'] = 0;
     }
 
+    $event_templates->set_var('lang_eventid', $LANG_CALJP_ADMIN[34]);
     $event_templates->set_var('event_id', $A['eid']);
     $event_templates->set_var('lang_eventtitle', $LANG_ADMIN['title']);
     $A['title'] = str_replace('{','&#123;',$A['title']);
@@ -239,13 +250,22 @@ function CALENDARJP_editEvent ($mode, $A, $msg = '')
     // Combine date/time for easier manipulation
     $A['datestart'] = trim ($A['datestart'] . ' ' . $A['timestart']);
     if (empty ($A['datestart'])) {
-        $start_stamp = time ();
+// ------------------------------>>
+//        $start_stamp = time ();
+// ------------------------------||
+        if (!empty($A['month']) && !empty($A['day']) && !empty($A['year']) && !empty($A['hour'])) {
+            $start_stamp = mktime($A['hour'], 0, 0, $A['month'], $A['day'], $A['year']);
+        } else {
+            $start_stamp = time ();
+        }
+// ------------------------------<<
     } else {
         $start_stamp = strtotime ($A['datestart']);
     }
     $A['dateend'] = trim ($A['dateend'] . ' ' . $A['timeend']);
     if (empty ($A['dateend'])) {
-        $end_stamp = time ();
+//        $end_stamp = time ();
+        $end_stamp = $start_stamp;
     } else {
         $end_stamp = strtotime ($A['dateend']);
     }
@@ -263,11 +283,6 @@ function CALENDARJP_editEvent ($mode, $A, $msg = '')
     } else {
         $startampm = 'am';
     }
-//  if ($start_hour >= 12) {
-//      $startampm = '午後';
-//  } else {
-//      $startampm = '午前';
-//  }
 
     $start_hour_24 = $start_hour % 24;
     if ($start_hour > 12) {
@@ -283,11 +298,6 @@ function CALENDARJP_editEvent ($mode, $A, $msg = '')
     } else {
         $endampm = 'am';
     }
-//  if ($end_hour >= 12) {
-//      $endampm = '午後';
-//  } else {
-//      $endampm = '午前';
-//  }
 
     $end_hour_24 = $end_hour % 24;
     if ($end_hour > 12) {
@@ -372,6 +382,9 @@ function CALENDARJP_editEvent ($mode, $A, $msg = '')
     $event_templates->set_var('hits', COM_numberFormat ($A['hits']));
     $event_templates->set_var('lang_save', $LANG_ADMIN['save']);
     $event_templates->set_var('lang_cancel', $LANG_ADMIN['cancel']);
+    $event_templates->set_var('lang_tail_year', $LANG_CALJP_ADMIN['tail_year']);
+    $event_templates->set_var('lang_tail_month', $LANG_CALJP_ADMIN['tail_month']);
+    $event_templates->set_var('lang_tail_day', $LANG_CALJP_ADMIN['tail_day']);
 
     // user access info
     $event_templates->set_var('lang_accessrights',$LANG_ACCESS['accessrights']);
@@ -387,9 +400,11 @@ function CALENDARJP_editEvent ($mode, $A, $msg = '')
                               SEC_getGroupDropdown ($A['group_id'], $access));
     $event_templates->set_var('lang_permissions', $LANG_ACCESS['permissions']);
     $event_templates->set_var('lang_permissionskey', $LANG_ACCESS['permissionskey']);
+    $event_templates->set_var('lang_perm_key', $LANG_ACCESS['permissionskey']);
     $event_templates->set_var('permissions_editor', SEC_getPermissionsHTML($A['perm_owner'],$A['perm_group'],$A['perm_members'],$A['perm_anon']));
+    $event_templates->set_var('lang_permissions_msg', $LANG_ACCESS['permmsg']);
     $event_templates->set_var('gltoken_name', CSRF_TOKEN);
-    $event_templates->set_var('gltoken', SEC_createToken());
+    $event_templates->set_var('gltoken', $token);
     $event_templates->parse('output', 'editor');
     $retval .= $event_templates->finish($event_templates->get_var('output'));
     $retval .= COM_endBlock (COM_getBlockTemplate ('_admin_block', 'footer'));
@@ -440,12 +455,10 @@ function CALENDARJP_saveEvent ($eid, $title, $event_type, $url, $allday,
                 $perm_members, $perm_anon);
     }
     if (($access < 3) || !SEC_inGroup ($group_id)) {
-        $retval .= COM_siteHeader('menu', $MESSAGE[30]);
-        $retval .= COM_startBlock ($MESSAGE[30], '',
-                            COM_getBlockTemplate ('_msg_block', 'header'));
-        $retval .= $MESSAGE[31];
-        $retval .= COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
-        $retval .= COM_siteFooter();
+        $retval .= COM_siteHeader('menu', $MESSAGE[30])
+                . COM_showMessageText($MESSAGE[29], $MESSAGE[30])
+                . COM_siteFooter();
+
         COM_accessLog ("User {$_USER['username']} tried to illegally submit or edit event $eid.");
         return $retval;
     }
@@ -550,20 +563,22 @@ function CALENDARJP_saveEvent ($eid, $title, $event_type, $url, $allday,
 
     // clean 'em up
     if (($postmode == 'html') || ($postmode == 'adveditor')) {
-        $description = COM_checkHTML (COM_checkWords ($description));
+        $description = COM_checkHTML(COM_checkWords($description),
+                                     'calendarjp.edit');
     } else {
         $postmode = 'plaintext';
-        $description = htmlspecialchars (COM_checkWords ($description));
+        $description = htmlspecialchars(COM_checkWords($description));
     }
-    $description = addslashes ($description);
-    $title = addslashes (COM_checkHTML (COM_checkWords ($title)));
-    $location = addslashes (COM_checkHTML (COM_checkWords ($location)));
-    $address1 = addslashes (COM_checkHTML (COM_checkWords ($address1)));
-    $address2 = addslashes (COM_checkHTML (COM_checkWords ($address2)));
-    $city = addslashes (COM_checkHTML (COM_checkWords ($city)));
-    $zipcode =  addslashes (COM_checkHTML (COM_checkWords ($zipcode)));
-    $event_type = addslashes (strip_tags (COM_checkWords ($event_type)));
-    $url = addslashes (strip_tags ($url));
+    $description = addslashes($description);
+    $title = addslashes(strip_tags(COM_checkWords($title)));
+    $location = addslashes(COM_checkHTML(COM_checkWords($location),
+                                         'calendarjp.edit'));
+    $address1 = addslashes(strip_tags(COM_checkWords($address1)));
+    $address2 = addslashes(strip_tags(COM_checkWords($address2)));
+    $city = addslashes(strip_tags(COM_checkWords($city)));
+    $zipcode =  addslashes(strip_tags(COM_checkWords($zipcode)));
+    $event_type = addslashes(strip_tags(COM_checkWords($event_type)));
+    $url = addslashes(strip_tags($url));
 
     if ($allday == 0) {
         // Add 12 to make time on 24 hour clock if needed
@@ -612,17 +627,22 @@ function CALENDARJP_saveEvent ($eid, $title, $event_type, $url, $allday,
                                . '/plugins/calendarjp/index.php');
         }
 
+        $hits = DB_getItem($_TABLES['eventsjp'], 'hits', "eid = '$eid'");
+        if (empty($hits)) {
+            $hits = 0;
+        }
+
         DB_delete ($_TABLES['eventsubmissionjp'], 'eid', $eid);
 
         DB_save($_TABLES['eventsjp'],
                'eid,title,event_type,url,allday,datestart,dateend,timestart,'
                .'timeend,location,address1,address2,city,state,zipcode,description,'
                .'postmode,owner_id,group_id,perm_owner,perm_group,perm_members,'
-               .'perm_anon',
+               .'perm_anon,hits',
                "'$eid','$title','$event_type','$url',$allday,'$datestart',"
                ."'$dateend','$timestart','$timeend','$location','$address1',"
                ."'$address2','$city','$state','$zipcode','$description','$postmode',"
-               ."$owner_id,$group_id,$perm_owner,$perm_group,$perm_members,$perm_anon");
+               ."$owner_id,$group_id,$perm_owner,$perm_group,$perm_members,$perm_anon,$hits");
         if (DB_count ($_TABLES['personal_eventsjp'], 'eid', $eid) > 0) {
             $result = DB_query ("SELECT uid FROM {$_TABLES['personal_eventsjp']} "
                                ."WHERE eid = '{$eid}'");
@@ -641,6 +661,8 @@ function CALENDARJP_saveEvent ($eid, $title, $event_type, $url, $allday,
                        ."$perm_anon,{$P['uid']},'$location','$timestart','$timeend'");
             }
         }
+
+        PLG_itemSaved($eid, 'calendarjp');
         COM_rdfUpToDateCheck('calendarjp', $event_type, $eid);
 
         return PLG_afterSaveSwitch (
@@ -732,6 +754,7 @@ if (($mode == $LANG_ADMIN['delete']) && !empty ($LANG_ADMIN['delete'])) {
     $eid = COM_applyFilter ($_REQUEST['eid']);
     $result = DB_query ("SELECT * FROM {$_TABLES['eventsjp']} WHERE eid ='$eid'");
     $A = DB_fetchArray ($result);
+    $A['hits'] = 0;
     $A['eid'] = COM_makesid ();
     $A['owner_id'] = $_USER['uid'];
     $display .= COM_siteHeader ('menu', $LANG_CALJP_ADMIN[1]);
@@ -752,6 +775,26 @@ if (($mode == $LANG_ADMIN['delete']) && !empty ($LANG_ADMIN['delete'])) {
         if (isset ($_REQUEST['timestart'])) {
             $A['timestart'] = COM_applyFilter ($_REQUEST['timestart']);
         }
+
+// Added ------------------------>>
+        $A['hour'] = '';
+        $A['month'] = '';
+        $A['day'] = '';
+        $A['year'] = '';
+        if (isset ($_REQUEST['hour'])) {
+            $A['hour'] = COM_applyFilter ($_REQUEST['hour'],true);
+        }
+        if (isset ($_REQUEST['month'])) {
+            $A['month'] = COM_applyFilter ($_REQUEST['month'],true);
+        }
+        if (isset ($_REQUEST['day'])) {
+            $A['day'] = COM_applyFilter ($_REQUEST['day'],true);
+        }
+        if (isset ($_REQUEST['year'])) {
+            $A['year'] = COM_applyFilter ($_REQUEST['year'],true);
+        }
+// Added ------------------------<<
+
     } else {
         $result = DB_query ("SELECT * FROM {$_TABLES['eventsjp']} WHERE eid ='$eid'");
         $A = DB_fetchArray ($result);
@@ -785,6 +828,7 @@ if (($mode == $LANG_ADMIN['delete']) && !empty ($LANG_ADMIN['delete'])) {
     $display .= CALENDARJP_listevents();
     $display .= COM_siteFooter ();
 }
-echo $display;
+
+COM_output($display);
 
 ?>
