@@ -2,13 +2,13 @@
 
 /* Reminder: always indent with 4 spaces (no tabs). */
 // +---------------------------------------------------------------------------+
-// | Geeklog 1.5                                                               |
+// | Geeklog 1.6                                                               |
 // +---------------------------------------------------------------------------+
 // | lib-syndication.php                                                       |
 // |                                                                           |
 // | Geeklog syndication library.                                              |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2003-2008 by the following authors:                         |
+// | Copyright (C) 2003-2009 by the following authors:                         |
 // |                                                                           |
 // | Authors: Dirk Haun        - dirk AT haun-online DOT de                    |
 // |          Michael Jervis   - mike AT fuckingbrit DOT com                   |
@@ -29,31 +29,30 @@
 // | Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.           |
 // |                                                                           |
 // +---------------------------------------------------------------------------+
-//
-// $Id: lib-syndication.php,v 1.40 2008/02/17 15:02:36 dhaun Exp $
+
+if (strpos(strtolower($_SERVER['PHP_SELF']), 'lib-syndication.php') !== false) {
+    die('This file can not be used on its own!');
+}
+
+if ($_CONF['trackback_enabled']) {
+    require_once $_CONF['path_system'] . 'lib-trackback.php';
+}
 
 // set to true to enable debug output in error.log
 $_SYND_DEBUG = false;
 
-if (strpos ($_SERVER['PHP_SELF'], 'lib-syndication.php') !== false) {
-    die ('This file can not be used on its own!');
-}
-
-if ($_CONF['trackback_enabled']) {
-    require_once ($_CONF['path_system'] . 'lib-trackback.php');
-}
-
 /**
 * Check if a feed for all stories needs to be updated.
 *
+* @param    boolean $frontpage_only true: only articles shown on the frontpage
 * @param    string  $update_info    list of story ids
 * @param    string  $limit          number of entries or number of hours
 * @param    string  $updated_topic  (optional) topic to be updated
 * @param    string  $updated_id     (optional) entry id to be updated
-* @return   bool                    false = feed needs to be updated
+* @return   boolean                 false = feed needs to be updated
 *
 */
-function SYND_feedUpdateCheckAll( $update_info, $limit, $updated_topic = '', $updated_id = '' )
+function SYND_feedUpdateCheckAll( $frontpage_only, $update_info, $limit, $updated_topic = '', $updated_id = '' )
 {
     global $_CONF, $_TABLES, $_SYND_DEBUG;
 
@@ -76,6 +75,8 @@ function SYND_feedUpdateCheckAll( $update_info, $limit, $updated_topic = '', $up
         $limitsql = ' LIMIT 10';
     }
 
+    $sids = array ();
+
     // get list of topics that anonymous users have access to
     $tresult = DB_query( "SELECT tid FROM {$_TABLES['topics']}"
                          . COM_getPermSQL( 'WHERE', 1 ));
@@ -90,23 +91,26 @@ function SYND_feedUpdateCheckAll( $update_info, $limit, $updated_topic = '', $up
     {
         $tlist = "'" . implode( "','", $topiclist ) . "'";
         $where .= " AND (tid IN ($tlist))";
-    }
 
-    $result = DB_query( "SELECT sid FROM {$_TABLES['stories']} WHERE draft_flag = 0 AND date <= NOW() $where AND perm_anon > 0 ORDER BY date DESC $limitsql" );
-    $nrows = DB_numRows( $result );
-
-    $sids = array ();
-    for( $i = 0; $i < $nrows; $i++ )
-    {
-        $A = DB_fetchArray( $result );
-
-        if( $A['sid'] == $updated_id )
-        {
-            // no need to look any further - this feed has to be updated
-            return false;
+        if ($frontpage_only) {
+            $where .= ' AND frontpage = 1';
         }
 
-        $sids[] = $A['sid'];
+        $result = DB_query( "SELECT sid FROM {$_TABLES['stories']} WHERE draft_flag = 0 AND date <= NOW() $where AND perm_anon > 0 ORDER BY date DESC $limitsql" );
+        $nrows = DB_numRows( $result );
+
+        for( $i = 0; $i < $nrows; $i++ )
+        {
+            $A = DB_fetchArray( $result );
+
+            if( $A['sid'] == $updated_id )
+            {
+                // no need to look any further - this feed has to be updated
+                return false;
+            }
+
+            $sids[] = $A['sid'];
+        }
     }
     $current = implode( ',', $sids );
 
@@ -125,7 +129,7 @@ function SYND_feedUpdateCheckAll( $update_info, $limit, $updated_topic = '', $up
 * @param    string  $limit          number of entries or number of hours
 * @param    string  $updated_topic  (optional) topic to be updated
 * @param    string  $updated_id     (optional) entry id to be updated
-* @return   bool                    false = feed needs to be updated
+* @return   boolean                 false = feed needs to be updated
 *
 */
 function SYND_feedUpdateCheckTopic( $tid, $update_info, $limit, $updated_topic = '', $updated_id = '' )
@@ -151,7 +155,7 @@ function SYND_feedUpdateCheckTopic( $tid, $update_info, $limit, $updated_topic =
         $limitsql = ' LIMIT 10';
     }
 
-    $result = DB_query( "SELECT sid FROM {$_TABLES['stories']} WHERE draft_flag = 0 AND date <= NOW() AND tid = '$tid' AND perm_anon > 0 ORDER BY date DESC $limitsql" );
+    $result = DB_query( "SELECT sid FROM {$_TABLES['stories']} WHERE draft_flag = 0 AND date <= NOW() AND tid = '$tid'" . COM_getTopicSQL('AND', 1) . " AND perm_anon > 0 ORDER BY date DESC $limitsql" );
     $nrows = DB_numRows( $result );
 
     $sids = array ();
@@ -179,30 +183,32 @@ function SYND_feedUpdateCheckTopic( $tid, $update_info, $limit, $updated_topic =
 /**
 * Check if the contents of Geeklog's built-in feeds need to be updated.
 *
-* @param    string  topic           indicator of the feed's "topic"
-* @param    string  limit           number of entries or number of hours
-* @param    string  updated_topic   (optional) specific topic to update
-* @param    string  updated_id      (optional) specific id to update
-* @return   bool                    false = feed has to be updated, true = ok
+* @param    string  $topic          indicator of the feed's "topic"
+* @param    string  $update_data    comma-sep. list of updated ids
+* @param    string  $limit          number of entries or number of hours
+* @param    string  $updated_topic  (optional) specific topic to update
+* @param    string  $updated_id     (optional) specific id to update
+* @return   boolean                 false = feed has to be updated, true = ok
 *
 */
-function SYND_feedUpdateCheck( $topic, $update_data, $limit, $updated_topic = '', $updated_id = '' )
+function SYND_feedUpdateCheck($topic, $update_data, $limit, $updated_topic = '', $updated_id = '')
 {
     $is_current = true; 
 
-    switch( $topic )
-    {
-        case '::all':
-        {
-            $is_current = SYND_feedUpdateCheckAll( $update_data, $limit,
-                            $updated_topic, $updated_id );
-        }
+    switch($topic) {
+    case '::all':
+        $is_current = SYND_feedUpdateCheckAll(false, $update_data, $limit,
+                            $updated_topic, $updated_id);
         break;
-        default:
-        {
-            $is_current = SYND_feedUpdateCheckTopic( $topic, $update_data,
-                            $limit, $updated_topic, $updated_id );
-        }
+
+    case '::frontpage':
+        $is_current = SYND_feedUpdateCheckAll(true, $update_data, $limit,
+                            $updated_topic, $updated_id);
+        break;
+
+    default:
+        $is_current = SYND_feedUpdateCheckTopic($topic, $update_data,
+                            $limit, $updated_topic, $updated_id);
         break;
     }
 
@@ -265,7 +271,19 @@ function SYND_getFeedContentPerTopic( $tid, $limit, &$link, &$update, $contentLe
             $storytext = SYND_truncateSummary( $fulltext, $contentLength );
 
             $fulltext = trim( $fulltext );
-            $fulltext = preg_replace( "/(\015)/", "", $fulltext );
+            $fulltext = str_replace(array("\015\012", "\015"), "\012", $fulltext);
+
+            if( $row['postmode'] == 'plaintext' ) 
+            {
+                if( !empty($storytext) )
+                {
+                    $storytext = nl2br($storytext);
+                }
+                if( !empty($fulltext) )
+                {
+                    $fulltext = nl2br($fulltext);
+                }
+            }
 
             $storylink = COM_buildUrl( $_CONF['site_url']
                                        . '/article.php?story=' . $row['sid'] );
@@ -303,6 +321,7 @@ function SYND_getFeedContentPerTopic( $tid, $limit, &$link, &$update, $contentLe
 /**
 * Get content for a feed that holds all stories.
 *
+* @param    boolean  $frontpage_only true: only articles shown on the frontpage
 * @param    string   $limit    number of entries or number of stories
 * @param    string   $link     link to homepage
 * @param    string   $update   list of story ids
@@ -311,10 +330,12 @@ function SYND_getFeedContentPerTopic( $tid, $limit, &$link, &$update, $contentLe
 * @return   array              content of the feed
 *
 */
-function SYND_getFeedContentAll( $limit, &$link, &$update, $contentLength, $feedType, $feedVersion, $fid)
+function SYND_getFeedContentAll($frontpage_only, $limit, &$link, &$update, $contentLength, $feedType, $feedVersion, $fid)
 {
     global $_TABLES, $_CONF, $LANG01;
 
+    $link = $_CONF['site_url'];
+
     $where = '';
     if( !empty( $limit ))
     {
@@ -339,6 +360,14 @@ function SYND_getFeedContentAll( $limit, &$link, &$update, $contentLength, $feed
     $tresult = DB_query( "SELECT tid,topic FROM {$_TABLES['topics']}"
                          . COM_getPermSQL( 'WHERE', 1 ));
     $tnumrows = DB_numRows( $tresult );
+
+    if ($tnumrows == 0) {
+        // no public topics
+        $update = '';
+
+        return array();
+    }
+
     $tlist = '';
     for( $i = 1; $i <= $tnumrows; $i++ )
     {
@@ -354,6 +383,9 @@ function SYND_getFeedContentAll( $limit, &$link, &$update, $contentLength, $feed
     {
         $where .= " AND (tid IN ($tlist))";
     }
+    if ($frontpage_only) {
+        $where .= ' AND frontpage = 1';
+    }
 
     $result = DB_query( "SELECT sid,tid,uid,title,introtext,bodytext,postmode,UNIX_TIMESTAMP(date) AS modified,commentcode,trackbackcode FROM {$_TABLES['stories']} WHERE draft_flag = 0 AND date <= NOW() $where AND perm_anon > 0 ORDER BY date DESC $limitsql" );
 
@@ -372,37 +404,46 @@ function SYND_getFeedContentAll( $limit, &$link, &$update, $contentLength, $feed
         $fulltext = PLG_replaceTags( $fulltext );
         $storytext = SYND_truncateSummary( $fulltext, $contentLength );
         $fulltext = trim( $fulltext );
-        $fulltext = preg_replace( "/(\015)/", "", $fulltext );
+        $fulltext = str_replace(array("\015\012", "\015"), "\012", $fulltext);
 
+        if( $row['postmode'] == 'plaintext' ) 
+        {
+            if( !empty($storytext) )
+            {
+                $storytext = nl2br($storytext);
+            }
+            if( !empty($fulltext) )
+            {
+                $fulltext = nl2br($fulltext);
+            }
+        }
+        
         $storylink = COM_buildUrl( $_CONF['site_url'] . '/article.php?story='
                                    . $row['sid'] );
-        $extensionTags = PLG_getFeedElementExtensions('article', $row['sid'], $feedType, $feedVersion, $fid, '::all');
+        $extensionTags = PLG_getFeedElementExtensions('article', $row['sid'], $feedType, $feedVersion, $fid, ($frontpage_only ? '::frontpage' : '::all'));
         if( $_CONF['trackback_enabled'] && ($feedType == 'RSS') && ($row['trackbackcode'] >= 0))
         {
             $trbUrl = TRB_makeTrackbackUrl( $row['sid'] );
             $extensionTags['trackbacktag'] = '<trackback:ping>'.htmlspecialchars($trbUrl).'</trackback:ping>';
         }
         $article = array( 'title'      => $storytitle,
-                            'summary'    => $storytext,
-                            'text'       => $fulltext,
-                            'link'       => $storylink,
-                            'uid'        => $row['uid'],
-                            'author'     => COM_getDisplayName( $row['uid'] ),
-                            'date'       => $row['modified'],
-                            'format'     => $row['postmode'],
-                            'topic'      => $topics[$row['tid']],
-                            'extensions' => $extensionTags
-                          );
+                          'summary'    => $storytext,
+                          'text'       => $fulltext,
+                          'link'       => $storylink,
+                          'uid'        => $row['uid'],
+                          'author'     => COM_getDisplayName( $row['uid'] ),
+                          'date'       => $row['modified'],
+                          'format'     => $row['postmode'],
+                          'topic'      => $topics[$row['tid']],
+                          'extensions' => $extensionTags
+                        );
         if($row['commentcode'] >= 0)
         {
             $article['commenturl'] = $storylink . '#comments';
         }
         $content[] = $article;
-
-
     }
 
-    $link = $_CONF['site_url'];
     $update = implode( ',', $sids );
 
     return $content;
@@ -425,10 +466,10 @@ function SYND_updateFeed( $fid )
     if( $A['is_enabled'] == 1 )
     {
         // Import the feed handling classes:
-        require_once( $_CONF['path_system']
-                      . '/classes/syndication/parserfactory.class.php' );
-        require_once( $_CONF['path_system']
-                      . '/classes/syndication/feedparserbase.class.php' );
+        require_once $_CONF['path_system']
+                     . '/classes/syndication/parserfactory.class.php';
+        require_once $_CONF['path_system']
+                     . '/classes/syndication/feedparserbase.class.php';
 
         // Load the actual feed handlers:
         $factory = new FeedParserFactory( $_CONF['path_system']
@@ -441,38 +482,35 @@ function SYND_updateFeed( $fid )
             $feed->encoding = $A['charset'];
             $feed->lang = $A['language'];
 
-            if( $A['type'] == 'geeklog' )
-            {
-                if( $A['topic'] == '::all')
-                {
-                    $content = SYND_getFeedContentAll( $A['limits'], $link,
-                                                       $data, $A['content_length'],
-                                                       $format[0], $format[1], $fid );
+            if ($A['type'] == 'article') {
+                if ($A['topic'] == '::all') {
+                    $content = SYND_getFeedContentAll(false, $A['limits'],
+                                    $link, $data, $A['content_length'],
+                                    $format[0], $format[1], $fid);
+                } elseif ($A['topic'] == '::frontpage') {
+                    $content = SYND_getFeedContentAll(true, $A['limits'],
+                                    $link, $data, $A['content_length'],
+                                    $format[0], $format[1], $fid);
+                } else { // feed for a single topic only
+                    $content = SYND_getFeedContentPerTopic($A['topic'],
+                                    $A['limits'], $link, $data,
+                                    $A['content_length'], $format[0],
+                                    $format[1], $fid);
                 }
-                else // feed for a single topic only
-                {
-                    $content = SYND_getFeedContentPerTopic( $A['topic'],
-                            $A['limits'], $link, $data, $A['content_length'],
-                            $format[0], $format[1], $fid );
-                }
-            }
-            else
-            {
-                $content = PLG_getFeedContent( $A['type'], $fid, $link, $data, $format[0], $format[1] );
+            } else {
+                $content = PLG_getFeedContent($A['type'], $fid, $link, $data, $format[0], $format[1]);
+
                 // can't randomly change the api to send a max length, so
                 // fix it here:
-                if ($A['content_length'] != 1)
-                {
-                    $count = count( $content );
-                    for( $i = 0; $i < $count; $i++ )
-                    {
+                if ($A['content_length'] != 1) {
+                    $count = count($content);
+                    for ($i = 0; $i < $count; $i++ ) {
                         $content[$i]['summary'] = SYND_truncateSummary(
-                                    $content[$i]['text'], $A['content_length'] );
+                                    $content[$i]['text'], $A['content_length']);
                     }
                 }
             }
-            if( empty( $link ))
-            {
+            if (empty($link)) {
                 $link = $_CONF['site_url'];
             }
 
@@ -501,7 +539,7 @@ function SYND_updateFeed( $fid )
                  * at least one does, then include the trackback namespace:
                  */
                 $trackbackenabled = false;
-                foreach($content as $item)
+                foreach ($content as $item)
                 {
                     if( array_key_exists('extensions', $item) &&
                         array_key_exists('trackbacktag', $item['extensions'])
@@ -584,27 +622,22 @@ function SYND_updateFeed( $fid )
 * @return   string              truncated text
 *
 */
-function SYND_truncateSummary( $text, $length )
+function SYND_truncateSummary($text, $length)
 {
-    if( $length == 0 )
-    {
+    if ($length == 0) {
         return '';
-    }
-    else
-    {
-        $text = stripslashes( $text );
-        $text = trim( $text );
-        $text = preg_replace( "/(\015)/", "", $text );
-        if(( $length > 3 ) && ( MBYTE_strlen( $text ) > $length ))
-        {
-            $text = substr( $text, 0, $length - 3 ) . '...';
+    } else {
+        $text = stripslashes($text);
+        $text = trim($text);
+        $text = str_replace(array("\015\012", "\015"), "\012", $text);
+        if (($length > 3) && (MBYTE_strlen($text) > $length)) {
+            $text = MBYTE_substr($text, 0, $length - 3) . '...';
         }
 
-        // Check if we broke html tag and storytext is now something
+        // Check if we broke an html tag and storytext is now something
         // like "blah blah <a href= ...". Delete "<*" if so.
-        if( strrpos( $text, '<' ) > strrpos( $text, '>' ))
-        {
-            $text = substr( $text, 0, strrpos( $text, '<' ) - 1 )
+        if (MBYTE_strrpos($text, '<' ) > MBYTE_strrpos($text, '>')) {
+            $text = MBYTE_substr($text, 0, MBYTE_strrpos($text, '<'))
                   . ' ...';
         }
 
@@ -651,4 +684,19 @@ function SYND_getFeedUrl( $feedfile = '' )
     return $url;
 }
 
+/**
+* Helper function: Return MIME type for a feed format
+*
+* @param    string  $format     internal name of the feed format, e.g. Atom-1.0
+* @return   string              MIME type, e.g. application/atom+xml
+*
+*/
+function SYND_getMimeType($format)
+{
+    $fmt = explode('-', $format);
+    $type = strtolower($fmt[0]);
+
+    return 'application/' . $type . '+xml';
+}
+
 ?>
